@@ -100,7 +100,7 @@ int main(int argc, char **argv)
 	int summary_flag = 0;
 	int fail_on_finding = 0;
 	int scan_hidden_dirs = 0;
-	char *context_path = NULL;
+	struct string_list *context_paths = NULL;
 	char color = 0;  // 0 auto, 1 off, 2 on
 
 	struct string_list *config_disabled_checks = NULL;
@@ -163,7 +163,11 @@ int main(int argc, char **argv)
 
 		case CONTEXT_ID:
 			// Specify a path for context files
-			context_path = optarg;
+			if (!context_paths) {
+				context_paths = sl_from_str(optarg);
+			} else {
+				append_to_sl(context_paths, optarg);
+			}
 			// Don't parse system devel policies if a context is given
 			source_flag = 1;
 			break;
@@ -233,6 +237,11 @@ int main(int argc, char **argv)
 		case 'l':
 			// Set the severity level
 			severity = optarg[0];
+			if (!is_valid_severity(severity)) {
+				printf("Invalid argument '%s' given for option --level\n", optarg);
+				usage();
+				exit(EX_USAGE);
+			}
 			break;
 
 		case 'm':
@@ -303,7 +312,10 @@ int main(int argc, char **argv)
 		WARN_ON_INVALID_CHECK_ID(cur->string, "enabled on command line");
 	}
 
-	if (!config_filename) {
+	if (config_filename && 0 != access(config_filename, R_OK)) {
+		printf("%sError%s: No configuration file found at '%s'!\n", color_error(), color_reset(), config_filename);
+		exit(EX_USAGE);
+	} else if (!config_filename) {
 		config_filename = SYSCONFDIR "/selint.conf";    // Default install path
 		if (0 != access(config_filename, R_OK)) {
 			//No default config found
@@ -314,7 +326,7 @@ int main(int argc, char **argv)
 		}
 	}
 
-	struct config_check_data ccd;
+	struct config_check_data ccd = { ORDER_LAX, {}, true, true, NULL };
 
 	if (config_filename) {
 		char cfg_severity;
@@ -332,10 +344,6 @@ int main(int argc, char **argv)
 		// roles that we wouldn't otherwise know about
 		insert_into_decl_map("system_u", "__assumed__", DECL_USER);
 		insert_into_decl_map("object_r", "__assumed__", DECL_ROLE);
-
-		// initialize to default settings
-		ccd.order_conf = ORDER_LAX;
-		ccd.skip_checking_generated_fcs = true;
 	}
 
 	for (const struct string_list *config_check_id = config_disabled_checks; config_check_id; config_check_id = config_check_id->next) {
@@ -392,6 +400,7 @@ int main(int argc, char **argv)
 
 	char *modules_conf_path = NULL;
 	char *obj_perm_sets_path = NULL;
+	char *access_vector_path = NULL;
 
 	while (file) {
 		const char *suffix = (file->fts_pathlen > 3) ? (file->fts_path + file->fts_pathlen - 3) : NULL;
@@ -420,6 +429,10 @@ int main(int argc, char **argv)
 		           && !strcmp(file->fts_name, "obj_perm_sets.spt")) {
 			// TODO: Make obj_perm_sets.spt name configurable
 			obj_perm_sets_path = strdup(file->fts_path);
+		} else if (source_flag
+		           && !strcmp(file->fts_name, "access_vectors")) {
+			// TODO: Make access_vectors name configurable
+			access_vector_path = strdup(file->fts_path);
 		} else {
 			// Directories might get traversed twice: preorder and final visit.
 			// Print only the final visit
@@ -452,8 +465,10 @@ int main(int argc, char **argv)
 
 	fts_close(ftsp);
 
-	if (context_path) {
-		paths[0] = context_path;
+	struct string_list *context_path_node = context_paths;
+
+	while (context_path_node) {
+		paths[0] = context_path_node->string;
 		paths[1] = NULL;
 
 		ftsp = fts_open(paths, FTS_PHYSICAL | FTS_NOSTAT, NULL);
@@ -481,15 +496,80 @@ int main(int argc, char **argv)
                                    && !obj_perm_sets_path
                                    && 0 == strcmp(file->fts_name, "obj_perm_sets.spt")) {
 				obj_perm_sets_path = strdup(file->fts_path);
+			} else if (source_flag
+                                   && !access_vector_path
+                                   && 0 == strcmp(file->fts_name, "access_vectors")) {
+				access_vector_path = strdup(file->fts_path);
 			}
 			file = fts_read(ftsp);
 		}
 
 		fts_close(ftsp);
+		context_path_node = context_path_node->next;
 	}
 
+	free_string_list(context_paths);
 	free(paths);
 
+	// Load object classes and permissions
+	if (source_flag) {
+		if (access_vector_path) {
+			enum selint_error res = load_access_vectors_source(access_vector_path);
+			if (res != SELINT_SUCCESS) {
+				printf("%sWarning%s: Failed to parse access_vectors from %s: %d\n", color_warning(), color_reset(), access_vector_path, res);
+			} else {
+				print_if_verbose("Loaded classes and permissions from %s\n", access_vector_path);
+			}
+		} else {
+			printf("%sWarning%s: Failed to locate access_vectors file.\n", color_warning(), color_reset());
+		}
+
+		if (modules_conf_path) {
+			enum selint_error res =
+				load_modules_source(modules_conf_path);
+			if (res != SELINT_SUCCESS) {
+				printf("%sWarning%s: Failed to load modules from %s: %d\n", color_warning(), color_reset(), modules_conf_path, res);
+			} else {
+				print_if_verbose("Loaded modules from %s\n",
+				                 modules_conf_path);
+			}
+		} else {
+			printf("%sWarning%s: Failed to locate modules.conf file.\n", color_warning(), color_reset());
+		}
+
+		if (obj_perm_sets_path) {
+			enum selint_error res =
+				load_obj_perm_sets_source(obj_perm_sets_path);
+			if (res != SELINT_SUCCESS) {
+				printf("%sWarning%s: Failed to permission and class set macros from %s: %d\n", color_warning(), color_reset(), obj_perm_sets_path, res);
+			} else {
+				print_if_verbose("Loaded permission and class set macros from %s\n",
+				                 obj_perm_sets_path);
+			}
+		} else {
+			printf("%sWarning%s: Failed to locate obj_perm_sets.spt file.\n", color_warning(), color_reset());
+		}
+
+	} else {
+		enum selint_error r = load_access_vectors_kernel("/sys/fs/selinux/class");
+		if (r != SELINT_SUCCESS) {
+			if (r == SELINT_IO_ERROR) {
+				printf("%sNote%s: Failed to load classes and perms probably due to running on a SELinux disabled system.\n",
+				       color_note(), color_reset());
+			} else {
+				printf("%sWarning%s: Failed to load classes and perms from current kernel.\n",
+				       color_warning(), color_reset());
+			}
+		}
+
+		load_modules_normal();
+		enum selint_error res = load_devel_headers(context_if_files);
+		if (res != SELINT_SUCCESS) {
+			printf("%sWarning%s: Failed to load SELinux development header files.\n", color_warning(), color_reset());
+		}
+	}
+
+	/* Delay until support files have been parsed for check conditions. */
 	struct checks *ck = register_checks(severity,
 	                                    config_enabled_checks,
 	                                    config_disabled_checks,
@@ -505,49 +585,13 @@ int main(int argc, char **argv)
 		free_file_list(context_te_files);
 		free_file_list(context_if_files);
 		free(obj_perm_sets_path);
+		free(access_vector_path);
 		free(modules_conf_path);
 		return EX_CONFIG;
 	}
-	// Load object classes and permissions
-	if (source_flag) {
-		load_access_vectors_source();
-
-		if (modules_conf_path) {
-			enum selint_error res =
-				load_modules_source(modules_conf_path);
-			if (res != SELINT_SUCCESS) {
-				printf("%sWarning%s: Failed to load modules.conf: %d\n", color_warning(), color_reset(), res);
-			} else {
-				print_if_verbose("Loaded modules from %s\n",
-				                 modules_conf_path);
-			}
-		} else {
-			printf("%sWarning%s: Failed to locate modules.conf file.\n", color_warning(), color_reset());
-		}
-
-		if (obj_perm_sets_path) {
-			enum selint_error res =
-				load_obj_perm_sets_source(obj_perm_sets_path);
-			if (res != SELINT_SUCCESS) {
-				printf("%sWarning%s: Failed to load obj_perm_sets.spt: %d\n", color_warning(), color_reset(), res);
-			} else {
-				print_if_verbose("Loaded permission and class set macros from %s\n",
-				                 obj_perm_sets_path);
-			}
-		} else {
-			printf("%sWarning%s: Failed to locate obj_perm_sets.spt file.\n", color_warning(), color_reset());
-		}
-
-	} else {
-		load_access_vectors_normal("/sys/fs/selinux/class");
-		load_modules_normal();
-		enum selint_error res = load_devel_headers(context_if_files);
-		if (res != SELINT_SUCCESS) {
-			printf("%sWarning%s: Failed to load SELinux development header files.\n", color_warning(), color_reset());
-		}
-	}
 
 	free(obj_perm_sets_path);
+	free(access_vector_path);
 	free(modules_conf_path);
 
 	enum selint_error res = run_analysis(ck, te_files, if_files, fc_files, context_te_files, context_if_files, custom_fc_macros, &ccd);
@@ -585,6 +629,7 @@ int main(int argc, char **argv)
 	free_file_list(fc_files);
 	free_file_list(context_te_files);
 	free_file_list(context_if_files);
+	free_selint_config(&ccd);
 
 	if (fail_on_finding && found_issue && exit_code == EX_OK) {
 		return EX_DATAERR;
