@@ -18,6 +18,7 @@
 #define STRING_LIST_H
 
 #include <stddef.h>
+#include "selint_error.h"
 
 struct string_list {
 	char *string;
@@ -34,6 +35,10 @@ struct string_list *copy_string_list(const struct string_list *sl);
 struct string_list *sl_from_str(const char *string);
 struct string_list *sl_from_strn(const char *string, size_t len);
 
+// Return a string list with the given string as single item
+// Takes ownership of the given string
+struct string_list *sl_from_str_consume(char *string);
+
 // Return a string list with copies of the given strings
 struct string_list *sl_from_strs(int count, ...);
 
@@ -41,6 +46,11 @@ struct string_list *sl_from_strs(int count, ...);
 // Note: freeing the returned list will free both original string lists
 struct string_list *concat_string_lists(struct string_list *head, struct string_list *tail);
 
+// Append a copy of a string on the end of the given string list
+// Note: this traverses the string list.  In performance critical
+// situations with multiple appends, you should save a pointer to the end of the list
+enum selint_error append_to_sl(struct string_list *sl, const char *string);
+
 void free_string_list(struct string_list *list);
 
 #endif
