@@ -29,7 +29,8 @@
 #define EMPTY_TE_FILENAME POLICIES_DIR "empty.te"
 #define SYNTAX_ERROR_FILENAME POLICIES_DIR "syntax_error.te"
 #define BAD_RA_FILENAME POLICIES_DIR "bad_role_allow.te"
-#define DISABLE_COMMENT_FILENAME POLICIES_DIR "disable_comment.te"
+#define DISABLE_COMMENT_TE_FILENAME POLICIES_DIR "disable_comment.te"
+#define DISABLE_COMMENT_IF_FILENAME POLICIES_DIR "disable_comment.if"
 #define BOOL_DECLARATION_FILENAME POLICIES_DIR "bool_declarations.te"
 #define EXTENDED_TE_FILENAME POLICIES_DIR "extended_perms.te"
 #define IFDEF_BLOCK_FILENAME POLICIES_DIR "ifdef_block.te"
@@ -280,13 +281,13 @@ START_TEST (test_parse_bad_role_allow) {
 }
 END_TEST
 
-START_TEST (test_disable_comment) {
+START_TEST (test_disable_comment_te) {
 
 	set_current_module_name("disable_comment");
 
-	FILE *f = fopen(DISABLE_COMMENT_FILENAME, "r");
+	FILE *f = fopen(DISABLE_COMMENT_TE_FILENAME, "r");
 	ck_assert_ptr_nonnull(f);
-	struct policy_node *ast = yyparse_wrapper(f, DISABLE_COMMENT_FILENAME, NODE_TE_FILE);
+	struct policy_node *ast = yyparse_wrapper(f, DISABLE_COMMENT_TE_FILENAME, NODE_TE_FILE);
 	ck_assert_ptr_nonnull(ast);
 
 	ck_assert_ptr_nonnull(ast);
@@ -306,6 +307,29 @@ START_TEST (test_disable_comment) {
 }
 END_TEST
 
+START_TEST (test_disable_comment_if) {
+
+	set_current_module_name("disable_comment");
+
+	FILE *f = fopen(DISABLE_COMMENT_IF_FILENAME, "r");
+	ck_assert_ptr_nonnull(f);
+	struct policy_node *ast = yyparse_wrapper(f, DISABLE_COMMENT_IF_FILENAME, NODE_IF_FILE);
+	ck_assert_ptr_nonnull(ast);
+
+	ck_assert_ptr_nonnull(ast);
+	ck_assert_int_eq(NODE_IF_FILE, ast->flavor);
+	ck_assert_ptr_nonnull(ast->next);
+	ck_assert_int_eq(NODE_INTERFACE_DEF, ast->next->flavor);
+	ck_assert_str_eq("S-012", ast->next->exceptions);
+	ck_assert_ptr_null(ast->next->next);
+
+	free_policy_node(ast);
+	cleanup_parsing();
+	fclose(f);
+
+}
+END_TEST
+
 START_TEST (test_bool_declarations) {
 
 	set_current_module_name("bool_declarations");
@@ -831,7 +855,8 @@ static Suite *parsing_suite(void) {
 	tcase_add_test(tc_core, test_parse_empty_file);
 	tcase_add_test(tc_core, test_syntax_error);
 	tcase_add_test(tc_core, test_parse_bad_role_allow);
-	tcase_add_test(tc_core, test_disable_comment);
+	tcase_add_test(tc_core, test_disable_comment_te);
+	tcase_add_test(tc_core, test_disable_comment_if);
 	tcase_add_test(tc_core, test_bool_declarations);
 	tcase_add_test(tc_core, test_file_flavor_mismatch);
 	tcase_add_test(tc_core, test_extended_perms);
